==> lyx-1.4.0-cygwin.tar.gz: usr/local/share/lyx/etc/lyx-win.c <==
/* This is the wrapper program for LyX/Cygwin. Using this
 * wrapper program no DOS window will be present running LyX.
 * The bad side of this: no error output could be seen ;-)
 *
 * It launches the real binary program using native Windows
 * graphics lyx-winbin.exe, unless it is called lyx-x11.exe
 * in which case lyx-x11bin.exe gets started.
 *
 * compile this source with following options set:
 *
 *    gcc lyx-win.c -O2 -o lyx-win -static -Wall -Wno-format \
 *                   -Wstrict-prototypes -Wmissing-prototypes \
 *                   -mwindows -e _mainCRTStartup
 *
 * Claus Hentschel, 2002-01-17
 * Enrico Forestieri, 2006-03-11
 */
#include <stdio.h>            /* standard io library */
#include <stdlib.h>           /* standard library */
#include <unistd.h>           /* sleep , fork & exec */
#include <string.h>           /* standard string library */
#include <sys/cygwin.h>       /* cygwin_conv_to_posix_path */
#include <errno.h>

int RunningX(const char *);

/* RunningX() returns non-zero if the Xwindow system is running */

int RunningX(const char *xname)
{
    FILE *res;
    char buf[1024];
    int n = 0;
    sprintf(buf, "ps -efW | grep -i %s | wc -l", xname);
    res = popen(buf, "r");
    fscanf(res, "%d", &n);
    pclose(res);
    return(n);
}


int main (int argc, char **argv, char **environ)
{
    FILE *fp;
    char *s;
    char posixpath[8000];             /* converted path */
    char cmd[32000] = "lyx-winbin ";  /* user command */
    char *nargs[5] = {                /* execute with login /bin/bash */
	    "/bin/bash", "--login",
	    "-c" , cmd ,
	    NULL
    };
    int i = 1; /* just to count */

    /* ensure bash reads our global env changes */
    putenv("BASH_ENV=/etc/lyxprofile") ;

    /* check if the X11 version should be launched */
    if ((s = strrchr(argv[0],'-')) &&
	    (strcasecmp(s, "-x11") == 0 || strcasecmp(s, "-x11.exe") == 0))
    {
	char xname[256];

	/* Get the X server name from /etc/lyxprofile */
	fp = popen("grep XSERVERNAME /etc/lyxprofile | tr -d '\\r' | sed 's/.*= *\\(.*\\)$/\\1/'", "r");
	fgets(xname, sizeof(xname), fp);
	pclose(fp);
	xname[strlen(xname)-1] = 0;

	/* if the X server is not already running, try to start it through
	 * startxserver, otherwise bail out with the native version of LyX
	 */
	if (RunningX(xname))
	    strcpy(cmd, "lyx-x11bin ");
	else
	{
	    system("/usr/local/bin/startxserver");
	    sleep(1);
	    if (RunningX(xname))
		strcpy(cmd, "lyx-x11bin ");
	}
    }

    /* do for all "real" args */
    while (i < argc)
    {
	int done = 0;
	strcat(cmd, "\""); /* add quote before */
	cygwin_conv_to_posix_path(argv[i], posixpath) ;
	strcat(cmd, posixpath); /* add the argument */
	strcat(cmd, "\" "); /* add closing quote */
	s = strrchr(argv[i], '.');
	if (!done && strcasecmp(s, ".lyx") == 0 && (s = strrchr(posixpath,'/')))
	{
	    done = 1;
	    fp = fopen("/tmp/cdpath","w");
	    if (fp)
	    {
		*s = 0;
		fprintf(fp, "%s\n", posixpath);
		fclose(fp);
	    }
	}
	++i;
    }

    strcat(cmd, "</dev/null 1>/dev/null 2>&1");

    fprintf(stderr , "Command is: |%s|\n", cmd);
    execv("/bin/bash", nargs);  /* exec sub command */

    /* we should never reach here */
    perror("Execute failed");
    return(0) ; /* exit with no error */
}

==> lyx-1.4.2-cygwin.tar.gz: usr/local/share/lyx/etc/lyx-win.c <==
/* This is the wrapper program for LyX/Cygwin. Using this
 * wrapper program no DOS window will be present running LyX.
 * The bad side of this: no error output could be seen ;-)
 *
 * It launches the real binary program using native Windows
 * graphics lyx-qtwin.exe, unless it is called lyx-x11.exe
 * in which case lyx-qtx11.exe gets started.
 *
 * compile this source with following options set:
 *
 *    gcc lyx-win.c -O2 -o lyx-win -static -Wall -Wno-format \
 *                   -Wstrict-prototypes -Wmissing-prototypes \
 *                   -mwindows -e _mainCRTStartup
 *
 * Claus Hentschel, 2002-01-17
 * Enrico Forestieri, 2006-07-21
 */
#include <stdio.h>            /* standard io library */
#include <stdlib.h>           /* standard library */
#include <unistd.h>           /* sleep , fork & exec */
#include <string.h>           /* standard string library */
#include <limits.h>           /* PATH_MAX */
#include <sys/cygwin.h>       /* cygwin_conv_to_posix_path */
#include <errno.h>

int RunningX(const char *);

/* RunningX() returns non-zero if the Xwindow system is running */

int RunningX(const char *xname)
{
    FILE *res;
    char buf[1024];
    int n = 0;
    sprintf(buf, "ps -efW | grep -i %s | wc -l", xname);
    res = popen(buf, "r");
    fscanf(res, "%d", &n);
    pclose(res);
    return(n);
}


int main (int argc, char **argv, char **environ)
{
    FILE *fp;
    char *s;
    char posixpath[PATH_MAX];         /* converted path */
    char cmd[32000] = "lyx-qtwin ";   /* user command */
    char *nargs[5] = {                /* execute with login /bin/bash */
	    "/bin/bash", "--login",
	    "-c" , cmd ,
	    NULL
    };
    int i = 1; /* just to count */

    /* ensure bash reads our global env changes */
    putenv("BASH_ENV=/etc/lyxprofile") ;

    /* check if the X11 version should be launched */
    s = strrchr(argv[0],'-');
    if (s && (strcasecmp(s, "-x11") == 0 || strcasecmp(s, "-x11.exe") == 0))
    {
	char xname[256];

	/* Get the X server name from /etc/lyxprofile */
	fp = popen("grep XSERVERNAME /etc/lyxprofile | tr -d '\\r' | sed 's/.*= *\\(.*\\)$/\\1/'", "r");
	fgets(xname, sizeof(xname), fp);
	pclose(fp);
	xname[strlen(xname)-1] = 0;

	/* if the X server is not already running, try to start it through
	 * startxserver, otherwise bail out with the native version of LyX
	 */
	if (RunningX(xname))
	    strcpy(cmd, "lyx-qtx11 ");
	else
	{
	    system("/usr/local/bin/startxserver");
	    sleep(1);
	    if (RunningX(xname))
		strcpy(cmd, "lyx-qtx11 ");
	}
    }

    /* do for all "real" args */
    while (i < argc)
    {
	int done = 0;
	int lyxfile = (s = strrchr(argv[i], '.')) && strcasecmp(s, ".lyx") == 0;
	strcat(cmd, "\""); /* add quote before */
	cygwin_conv_to_posix_path(argv[i], posixpath) ;
	/* Hack to account for shares */
	if (lyxfile && argv[i][0] == '\\' && argv[i][1] != '\\')
	    strcat(cmd, "/");
	strcat(cmd, posixpath); /* add the argument */
	strcat(cmd, "\" "); /* add closing quote */
	if (!done && lyxfile && (s = strrchr(posixpath,'/')))
	{
	    done = 1;
	    fp = fopen("/tmp/cdpath","w");
	    if (fp)
	    {
		*s = 0;
		fprintf(fp, "%s\n", posixpath);
		fclose(fp);
	    }
	}
	++i;
    }

    strcat(cmd, "</dev/null 1>/dev/null 2>&1");

    /* fprintf(stderr , "Command is: |%s|\n", cmd); */
    execv("/bin/bash", nargs);  /* exec sub command */

    /* we should never reach here */
    perror("Execute failed");
    return(0) ; /* exit with no error */
}
